@@ -1,7 +1,7 @@
 package Getopt::Long::Negate::EN;
 
 our $DATE = '2016-01-03'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -52,7 +52,7 @@ Getopt::Long::Negate::EN - Better negation of boolean option names
 
 =head1 VERSION
 
-This document describes version 0.02 of Getopt::Long::Negate::EN (from Perl distribution Getopt-Long-Negate-EN), released on 2015-01-03.
+This document describes version 0.03 of Getopt::Long::Negate::EN (from Perl distribution Getopt-Long-Negate-EN), released on 2015-01-03.
 
 =head1 SYNOPSIS
 
@@ -66,10 +66,17 @@ This document describes version 0.02 of Getopt::Long::Negate::EN (from Perl dist
 
  @negs = negations_for_option('is-foo');      # ('isnt-foo')
  @negs = negations_for_option('isnt-foo');    # ('is-foo')
-
  @negs = negations_for_option('are-foo');     # ('isnt-foo')
  @negs = negations_for_option('arent-foo');   # ('arent-foo')
 
+ @negs = negations_for_option('has-foo');     # ('hasnt-foo')
+ @negs = negations_for_option('hasnt-foo');   # ('has-foo')
+ @negs = negations_for_option('have-foo');    # ('havent-foo')
+ @negs = negations_for_option('havent-foo');  # ('have-foo')
+
+ @negs = negations_for_option('can-foo');     # ('cant-foo')
+ @negs = negations_for_option('cant-foo');    # ('can-foo')
+
  @negs = negations_for_option('no-foo');      # ('foo')
 
 =head1 DESCRIPTION
